################################################################################
### Mechanistic Territory Model: Application to Montana Wolves ###
### Economical Defense of Resources Structures Territorial Space Use in a ###
###   Cooperative Carnivore: Sells et al., Proceedings of the Royal Society B ###

################################################################################

#### Plot Main Text Figures
library(dplyr)
library(ggplot2)
library(cowplot)

#### Import model predictions:
prim.pred <- read.csv(file = "Data/Data_1_Primary_Predictions.csv") # 2014 - 2019
prim.acc <- read.csv("Data/Data_2_Primary_Accuracy.csv") # 2014 - 2019
oth.acc <- read.csv("Data/Data_3_Other_Accuracy.csv") # 2008 - 2009

# Import observation data: 2014 - 2019
prim.obs <- read.csv("Data/Data_4_Primary_Observations.csv")

theme_set(theme_classic(base_size = 12))
source("https://gist.githubusercontent.com/benmarwick/2a1bb0133ff568cbe28d/raw/fb53bd97121f7f9ce947837ef1a4c65a73bffb3f/geom_flat_violin.R")
# above sources the half violin plots.

################################################################################
#### Figure 3, Predictions vs Observations
# 2014 - 2019: (n = 26 empirically observed packs)
bypack <- prim.acc %>% 
  group_by(pack) %>% # mean per pack
  summarise(predicted = mean(predicted),
            observed = mean(observed)) %>% 
  mutate(difference = abs(predicted - observed))
# Summary stats:
mean(bypack$observed)
sd(bypack$observed)
median(bypack$observed)
range(bypack$observed)
median(bypack$difference)
mean(bypack$difference)
# Temporarily omit outlier and resummarize:
bypack %>% 
  filter(pack != "FlatheadAlps") %>% 
  summarise(mean = mean(difference), 
            median = median(difference))
sum(bypack$difference <= 100)/26 
sum(bypack$difference <= 200)/26
sum(bypack$difference <= 300)/26
# Save results for plotting later:
bypack.recent <- bypack %>% mutate(Sample = "primary territories (2014 - 2019)")

#### 2008-2009: (n = 9 empirically observed packs)
bypack <- oth.acc %>% group_by(pack) %>% 
  summarize(predicted = mean(predicted),
            observed = mean(observed)) %>% 
  mutate(difference = abs(predicted - observed))
# Summary stats:
mean(bypack$observed)
sd(bypack$observed)
median(bypack$observed)
range(bypack$observed)
median(bypack$difference)
mean(bypack$difference)
# Temporarily omit outlier and resummarize:
bypack %>% 
  filter(pack != "WelcomeCreek") %>% 
  summarize(mean = mean(difference),
            median = median(difference))
sum(bypack$difference <= 100)/9 
sum(bypack$difference <= 200)/9
sum(bypack$difference <= 300)/9
bypack.former <- bypack %>% mutate(Sample = "other territories (2008 - 2009)")


#### Figure 3:
bypack <- rbind(bypack.recent, bypack.former)
bypack$Sample <- factor(bypack$Sample, levels=c("primary territories (2014 - 2019)", 
                                                "other territories (2008 - 2009)"))
Fig3 <- ggplot(bypack, aes(y = predicted, x= observed, color = Sample, shape = Sample)) + 
  geom_abline(intercept = 0, slope = 1, linetype = "solid")+
  geom_abline(intercept = 200, slope = 1, linetype = "dotted")+
  geom_abline(intercept = -200, slope = 1, linetype = "dotted")+
  scale_color_manual(values = c("turquoise3","orangered"))+
  scale_shape_manual(values = c(16,23))+
  geom_point(size = 2, fill = "orange")+
  scale_size_manual(values = c(4,2))+
  labs(x=expression(observed~territory~size~(km^2)), 
       y=expression(predicted~territory~size~(km^2))) +
  scale_x_continuous(expand = c(0, 0), breaks = scales::pretty_breaks(10), 
                     limits = c(0, 2300))+
  scale_y_continuous(expand = c(0, 0), breaks = scales::pretty_breaks(10), 
                     limits = c(0, 1200))+
  theme(panel.border = element_rect(fill=NA,colour = "black"),
        legend.position = c(.7, .07),
        legend.title = element_blank(),
        legend.background = element_blank(),
        legend.key.size = unit(0.4, "cm"))
tiff("Figure 3.tif", height=2900, width=2900,
     units="px", compression = c("none"), res=600, pointsize = 12)
Fig3
dev.off()

################################################################################
#### Figure 4, Ecoregional Predictions 

data.plot <- prim.pred %>% 
  mutate(Ecoregion = as.factor(Ecoregion))
prim.obs$Ecoregion <- as.factor(prim.obs$Ecoregion) 
colorder <- c("43","42","17","41","16","15")
eco.cols <- c("palegreen4","palegreen3","lawngreen","aquamarine2","goldenrod2","gold")

Fig4 <- ggplot(data.plot, aes(x=Ecoregion,y=Total.size, fill = Ecoregion))+
  geom_flat_violin(position = position_nudge(x = .25, y = 0),adjust =2, trim = FALSE)+
  geom_point(position = position_jitter(width = .15), size = .25, alpha = 0.5, 
             aes(color = Ecoregion))+
  coord_flip()+
  labs(y = expression(Territory~size~(km^2)))+  
  geom_point(size = 6,position = position_nudge(x = .25, y = 0), data = prim.obs, 
             col = "black", shape='*') + # Observations
  scale_x_discrete(limits=colorder,labels=c("Northwestern\nGreat Plains",
                                            "Northwestern\nGlaciated Plains",
                                            "Middle\nRockies",
                                            "Canadian\nRockies",
                                            "Idaho\nBatholith",
                                            "Northern\nRockies")) +
  scale_y_continuous(breaks = seq(0,2200,200), limits = c(0, 2300))+
  scale_fill_manual(values = c(eco.cols))+  
  scale_color_manual(values = c(eco.cols))+  
  theme(legend.position = "none",
        axis.title.y = element_blank())+
  geom_point(aes(x=6.35, y=1730), size = 6, shape=19, col = "palegreen4")+
  geom_point(aes(x=6.25, y=1730), size = 6.5, shape=15, col = "white")+
  geom_point(aes(x=6.3, y=1720), size = 0.75, shape=20, col = "palegreen4")+
  geom_point(aes(x=6.3, y=1740), size = 0.75, shape=20, col = "palegreen4")+
  annotate("text", x = 6.35, y = 1810, hjust=0, label = "Predictions")+
  geom_point(aes(x=6.1, y=1730), size = 6, color="black", shape='*')+
  annotate("text", x = 6.1, y = 1810, hjust=0, label = "Observations")

tiff("Figure 4.tif", height=3800, width=3300,
     units="px", compression = c("none"), res=600, pointsize = 12)
Fig4
dev.off()

################################################################################
#### Figure 5, Effects of Prey, Competition, and Mortality Risk 

#### Panel A & B:
data.summer <- prim.pred %>% # create copies, give same names to columns.
  mutate(food.abundance = A.S.sum.B / Total.size)
data.winter <- prim.pred %>% 
  mutate(food.abundance = A.W.sum.B / Total.size)
# A.S.sum.B and A.W.sum.B were total B in territory for summer and winter.
# Calculated mean per patch to get data comparable to observed territories.

data.summer.smooth <- data.summer %>% # Don't extend smooths where limited data 
  filter(food.abundance < quantile(food.abundance, 0.975)) %>%
  filter(food.abundance > quantile(food.abundance, 0.025))
data.winter.smooth <- data.winter %>% 
  filter(food.abundance < quantile(food.abundance, 0.975)) %>%
  filter(food.abundance > quantile(food.abundance, 0.025))

real.summer <- prim.obs %>% # create copies of observed data, give same names to columns.
  mutate(food.abundance = summer.food.abundance) 
real.winter <- prim.obs %>% 
  mutate(food.abundance = winter.food.abundance)

Fig5a.ts <- ggplot(data.summer, aes(food.abundance, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#00CC66")+
  geom_smooth(data = data.summer.smooth,
              size = 2, span = 1,  fill=NA, color="#009900", method = "loess") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(1, 5.5))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(y=expression(Territory~size~(km^2)),x="Summer prey density",
       title = "A.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        axis.text.x = element_blank(),
        axis.title.x = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))+
  geom_point(data=real.summer, size = 6, shape='*', color = "#330000")

Fig5a.o <- ggplot(data.summer, aes(food.abundance, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#00CC66")+
  geom_smooth(data = data.summer.smooth,
              size = 2, span = 1,  fill=NA, color="#009900", method = "loess") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(1, 5.5))+
  scale_y_continuous(breaks = scales::pretty_breaks(7))+
  labs(y="Territory overlap (%)", x="Summer prey density") + 
  theme(legend.position = "none",
        panel.border = element_rect(fill=NA,colour = NA),
        plot.margin = unit(c(0,0,0,0), "cm"))

Fig5b.ts <- ggplot(data.winter, aes(food.abundance, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#3399FF")+
  geom_smooth(data = data.winter.smooth,
              size = 2, span = 1,  fill=NA, color="#003399", method = "loess") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 9))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(title = "B.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        axis.title = element_blank(),
        axis.text = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm")) +
  geom_point(aes(x=5.5, y=2200), size = 2, shape=1, col = "#003399")+ 
  annotate("text", x = 5.7, y = 2200, hjust=0, label = "Predictions")+
  geom_point(aes(x=5.5, y=2000), size = 6, shape='*', color = "#330000")+ 
  annotate("text", x = 5.7, y = 2000, hjust=0, label = "Observations") +
  geom_point(data=real.winter, size = 6, shape='*', color = "#330000")

Fig5b.o <- ggplot(data.winter, aes(food.abundance, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#3399FF")+
  geom_smooth(data = data.winter.smooth,
              size = 2, span = 1, method = "loess",  fill=NA, color="#003399") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 9))+
  scale_y_continuous(breaks = scales::pretty_breaks(7))+
  labs(x="Winter prey density") + 
  theme(legend.position = "none",
        panel.border = element_rect(fill=NA,colour = NA),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

#### Panel C:
# Transforms prediction data to same as prim.obs observations version:
prim.pred <- prim.pred %>% 
  mutate(compdensity.ttotal = Competitors.nearby / Total.size * 100)

data.smooth <- prim.pred %>% 
  filter(compdensity.ttotal < quantile(compdensity.ttotal, 0.975)) %>%
  filter(compdensity.ttotal > quantile(compdensity.ttotal, 0.025))

Fig5c.ts <- ggplot(prim.pred, aes(compdensity.ttotal, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#FF9000")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "#CC3300", fill=NA)+
  scale_x_continuous(breaks = scales::pretty_breaks(6), limits = c(0,6))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(y=expression(Territory~size~(km^2)),title = "C.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        plot.margin = unit(c(0.5,0,0,0), "cm"))+
  geom_point(data = prim.obs, size = 5, shape='*')

Fig5c.o <- ggplot(prim.pred, aes(compdensity.ttotal, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.15, height = 0.15), 
              alpha = 0.15, color = "#FF9000")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "#CC3300", fill=NA)+
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 6))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 100))+
  labs(x="Competitor density", y="Territory overlap (%)")+
  theme(legend.position = "none",
        plot.caption = element_text(hjust = 0.5, face = "italic"),
        panel.border = element_rect(fill=NA,colour = NA),
        plot.margin = unit(c(0,0,0,0), "cm"))

#### Panel D:
# Divide output by territory size to get mean human density per km2. 
prim.pred <- prim.pred %>% 
  mutate(Mean.human.dens.per.patch = Human.density.in.territory / Total.size)

data.smooth <- prim.pred %>% 
  filter(Mean.human.dens.per.patch < quantile(Mean.human.dens.per.patch, 0.975)) %>%
  filter(Mean.human.dens.per.patch > quantile(Mean.human.dens.per.patch, 0.025))

Fig5d.ts <- ggplot(prim.pred, aes(Mean.human.dens.per.patch, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.15, height = 0.15), 
              alpha = 0.08, color = "tomato2")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "firebrick3", fill=NA) +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 12))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(title = "D.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        plot.caption = element_text(hjust = 0.5),
        axis.title = element_blank(),
        axis.text = element_blank(),
        plot.margin = unit(c(0.5,0,0,0), "cm"))+
  geom_point(data = prim.obs, size = 5, shape='*')

Fig5d.o <- ggplot(prim.pred, aes(Mean.human.dens.per.patch, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.15, height = 0.15), 
              alpha = 0.08, color = "tomato2")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "firebrick3", fill=NA) +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 12))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 100))+
  labs(x="Human density")+ 
  theme(legend.position = "none",
        panel.border = element_rect(fill=NA,colour = NA),
        plot.caption = element_text(hjust = 0.5),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

# Combine all: (jittering & alignment means drops some outer pts)
Fig5a <- plot_grid(Fig5a.ts, Fig5a.o, ncol=1, align = c("v"))
Fig5b <- plot_grid(Fig5b.ts, Fig5b.o, ncol=1, align = c("v"))
Fig5c <- plot_grid(Fig5c.ts, Fig5c.o, ncol=1, align = c("v"))
Fig5d <- plot_grid(Fig5d.ts, Fig5d.o, ncol=1, align = c("v"))
Fig5 <- plot_grid(Fig5a, Fig5b, Fig5c, Fig5d, ncol=2, 
                           rel_widths = c(1,0.85,1,0.85),
                           rel_heights = c(0.9,1))

tiff("Figure 5.tif", height=6000, width=3800, 
     units="px", compression = c("none"), res=600, pointsize = 12)
Fig5
dev.off()

################################################################################
#### Figure 6, Seasonal Patterns
data.summer <- prim.pred %>% 
  mutate(Percent.seasonal.overlap = Sum.s.overlap / Sum.s.selected.patches *100) %>% 
  select(c(Sum.s.selected.patches, Percent.seasonal.overlap)) %>% 
  mutate(season = "summer") %>% 
  rename(Territory.size = Sum.s.selected.patches) # seasonal territory size
data.winter <- prim.pred %>% 
  mutate(Percent.seasonal.overlap = Sum.w.overlap / Sum.w.selected.patches *100) %>% 
  select(c(Sum.w.selected.patches, Percent.seasonal.overlap)) %>% 
  mutate(season = "winter") %>% 
  rename(Territory.size = Sum.w.selected.patches)
data.plot <- rbind(data.summer, data.winter)
seas.cols <- c("chartreuse4","skyblue3")
data.plot$Group[data.plot$season == "summer"] <- 1
data.plot$Group[data.plot$season == "winter"] <- 2

Fig6.ts <- ggplot(data.plot, aes(x=Territory.size, color = season, fill = season))+
  geom_density(alpha = 0.4)+
  labs(x = expression(seasonal~territory~size~(km^2)))+  
  scale_x_continuous(breaks = seq(0,1300,200), limits = c(0,NA))+
  scale_fill_manual(values = c(seas.cols))+  
  scale_color_manual(values = c(seas.cols))+  
  theme(legend.position = "none",
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.line.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

Fig6.o <- ggplot(data.plot, aes(x=Percent.seasonal.overlap, color = season, fill = season))+
  geom_density(alpha = 0.4)+
  labs(x = "seasonal territory overlap (%)")+  
  scale_x_continuous(breaks = seq(0,100,10), limits = c(0,100))+
  scale_fill_manual(values = c(seas.cols))+  
  scale_color_manual(values = c(seas.cols))+  
  theme(legend.position = c(0.7, 0.7),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.line.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

Fig6 <- plot_grid(Fig6.ts, Fig6.o, ncol=2, align = c("hv"))

tiff("Figure 6.tif", height=2200, width=4400,
     units="px", compression = c("none"), res=600, pointsize = 12)
Fig6
dev.off()
