################################################################################
### Mechanistic Territory Model: Application to Montana Wolves ###
### Economical Defense of Resources Structures Territorial Space Use in a ###
###   Cooperative Carnivore: Sells et al., Proceedings of the Royal Society B ###

################################################################################

#### Plot Results for SI
library(dplyr)
library(ggplot2)
library(cowplot)

#### Import model predictions:
oth.pred <- read.csv(file = "Data/Data_SI_1_Other_Predictions.csv") # 2008 - 2009
prey.pred <- read.csv(file = "Data/Data_SI_2_Prey_Predictions.csv") # prey runs (App C)
comp.pred <- read.csv(file = "Data/Data_SI_3_Competition_Predictions.csv") # competition runs (App C)

# Import observation data: 2008 - 2009
oth.obs <- read.csv("Data/Data_SI_4_Other_Observations.csv")

################################################################################
#### Figure S10
#### SI Version of Figure 4, Ecoregional Predictions for Other (2008 - 2009) Data

theme_set(theme_classic(base_size = 12))
source("https://gist.githubusercontent.com/benmarwick/2a1bb0133ff568cbe28d/raw/fb53bd97121f7f9ce947837ef1a4c65a73bffb3f/geom_flat_violin.R")
# above sources the half violin plots.

data.plot <- oth.pred %>% # Create a copy to work with.
  mutate(Ecoregion = as.factor(Ecoregion))
oth.obs$Ecoregion <- as.factor(oth.obs$Ecoregion) 
colorder <- c("43","42","17","41","16","15")
eco.cols <- c("palegreen4","palegreen3","lawngreen","aquamarine2","goldenrod2","gold")

Fig10 <- ggplot(data.plot, aes(x=Ecoregion,y=Total.size, fill = Ecoregion))+
  geom_flat_violin(position = position_nudge(x = .25, y = 0),adjust =2, trim = FALSE)+
  geom_point(position = position_jitter(width = .15), size = .25, alpha = 0.5, 
             aes(color = Ecoregion))+
  coord_flip()+
  labs(y = expression(Territory~size~(km^2)))+  
  geom_point(size = 6,position = position_nudge(x = .25, y = 0), data = oth.obs, 
             col = "black", shape='*') + # Observations
  scale_x_discrete(limits=colorder,labels=c("Northwestern\nGreat Plains",
                                            "Northwestern\nGlaciated Plains",
                                            "Middle\nRockies",
                                            "Canadian\nRockies",
                                            "Idaho\nBatholith",
                                            "Northern\nRockies")) +
  scale_y_continuous(breaks = seq(0,2200,200), limits = c(0, 2300))+
  scale_fill_manual(values = c(eco.cols))+  
  scale_color_manual(values = c(eco.cols))+  
  theme(legend.position = "none",
        axis.title.y = element_blank())+
  geom_point(aes(x=6.35, y=1730), size = 6, shape=19, col = "palegreen4")+
  geom_point(aes(x=6.25, y=1730), size = 6.5, shape=15, col = "white")+
  geom_point(aes(x=6.3, y=1720), size = 0.75, shape=20, col = "palegreen4")+
  geom_point(aes(x=6.3, y=1740), size = 0.75, shape=20, col = "palegreen4")+
  annotate("text", x = 6.35, y = 1810, hjust=0, label = "Predictions")+
  geom_point(aes(x=6.1, y=1730), size = 6, color="black", shape='*')+
  annotate("text", x = 6.0, y = 1810, hjust=0, label = "Observations \n(2008/2009)")

tiff("Figure SI10.tif", height=1900, width=1650,
     units="px", compression = c("none"), res=300, pointsize = 12)
Fig10
dev.off()

################################################################################
#### Figure S11
#### SI Version of Figure 5, Effects of Prey, Competition, and Mortality Risk 

#### Panel A & B:
data.summer <- oth.pred %>% # create copies, give same names to columns.
  mutate(food.abundance = A.S.sum.B / Total.size) 
data.winter <- oth.pred %>% 
  mutate(food.abundance = A.W.sum.B / Total.size) 
# A.S.sum.B and A.W.sum.B were total B in territory for summer and winter.
# Calculated mean per patch to get data comparable to observed territories.

data.summer.smooth <- data.summer %>% # Don't extend smooths where limited data 
  filter(food.abundance < quantile(food.abundance, 0.975)) %>%
  filter(food.abundance > quantile(food.abundance, 0.025))
data.winter.smooth <- data.winter %>% 
  filter(food.abundance < quantile(food.abundance, 0.975)) %>%
  filter(food.abundance > quantile(food.abundance, 0.025))

real.summer <- oth.obs %>% # create copies of observed data, give same names to columns.
  mutate(food.abundance = summer.food.abundance) 
real.winter <- oth.obs %>% 
  mutate(food.abundance = winter.food.abundance)

Fig11a.ts <- ggplot(data.summer, aes(food.abundance, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#00CC66")+
  geom_smooth(data = data.summer.smooth,
              size = 2, span = 1,  fill=NA, color="#009900", method = "loess") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(1, 5.5))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(y=expression(Territory~size~(km^2)),x="Summer prey density",
       title = "A.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        axis.text.x = element_blank(),
        axis.title.x = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))+
  geom_point(data=real.summer, size = 6, shape='*', color = "#330000")

Fig11a.o <- ggplot(data.summer, aes(food.abundance, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#00CC66")+
  geom_smooth(data = data.summer.smooth,
              size = 2, span = 1,  fill=NA, color="#009900", method = "loess") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(1, 5.5))+
  scale_y_continuous(breaks = scales::pretty_breaks(7))+
  labs(y="Territory overlap (%)", x="Summer prey density") + 
  theme(legend.position = "none",
        panel.border = element_rect(fill=NA,colour = NA),
        plot.margin = unit(c(0,0,0,0), "cm"))

Fig11b.ts <- ggplot(data.winter, aes(food.abundance, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#3399FF")+
  geom_smooth(data = data.winter.smooth,
              size = 2, span = 1,  fill=NA, color="#003399", method = "loess") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 9))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(title = "B.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        axis.title = element_blank(),
        axis.text = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm")) +
  geom_point(aes(x=5, y=2200), size = 2, shape=1, col = "#003399")+ 
  annotate("text", x = 5.2, y = 2200, hjust=0, label = "Predictions")+
  geom_point(aes(x=5.0, y=2000), size = 6, shape='*', color = "#330000")+ 
  annotate("text", x = 5.2, y = 1800, hjust=0, label = "Observations \n(2008/2009)") +
  geom_point(data=real.winter, size = 6, shape='*', color = "#330000")

Fig11b.o <- ggplot(data.winter, aes(food.abundance, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#3399FF")+
  geom_smooth(data = data.winter.smooth,
              size = 2, span = 1, method = "loess",  fill=NA, color="#003399") +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 9))+
  scale_y_continuous(breaks = scales::pretty_breaks(7))+
  labs(x="Winter prey density") + 
  theme(legend.position = "none",
        panel.border = element_rect(fill=NA,colour = NA),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

#### Panel C:
# Transforms prediction data to same as oth.obs observations version:
oth.pred <- oth.pred %>% 
  mutate(compdensity.ttotal = (Competitors.nearby / Total.size) * 100)

data.smooth <- oth.pred %>% 
  filter(compdensity.ttotal < quantile(compdensity.ttotal, 0.975)) %>%
  filter(compdensity.ttotal > quantile(compdensity.ttotal, 0.025))

Fig11c.ts <- ggplot(oth.pred, aes(compdensity.ttotal, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.25, height = 0.25), 
              alpha = 0.15, color = "#FF9000")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "#CC3300", fill=NA)+
  scale_x_continuous(breaks = scales::pretty_breaks(6), limits = c(0,6))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(y=expression(Territory~size~(km^2)),title = "C.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        plot.margin = unit(c(0.5,0,0,0), "cm"))+
  geom_point(data = oth.obs, size = 5, shape='*')

Fig11c.o <- ggplot(oth.pred, aes(compdensity.ttotal, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.15, height = 0.15), 
              alpha = 0.15, color = "#FF9000")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "#CC3300", fill=NA)+
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 6))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 100))+
  labs(x="Competitor density", y="Territory overlap (%)")+
  theme(legend.position = "none",
        plot.caption = element_text(hjust = 0.5, face = "italic"),
        panel.border = element_rect(fill=NA,colour = NA),
        plot.margin = unit(c(0,0,0,0), "cm"))

#### Panel D:
# Divide output by territory size to get mean human density per km2. 
oth.pred <- oth.pred %>% 
  mutate(Mean.human.dens.per.patch = Human.density.in.territory / Total.size)

data.smooth <- oth.pred %>% 
  filter(Mean.human.dens.per.patch < quantile(Mean.human.dens.per.patch, 0.975)) %>%
  filter(Mean.human.dens.per.patch > quantile(Mean.human.dens.per.patch, 0.025))

Fig11d.ts <- ggplot(oth.pred, aes(Mean.human.dens.per.patch, Total.size))+
  geom_jitter(size=1, position = position_jitter(width = 0.15, height = 0.15), 
              alpha = 0.08, color = "tomato2")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "firebrick3", fill=NA) +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 16))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 2250))+
  labs(title = "D.") + 
  theme(legend.position = "none",
        plot.title = element_text(size = 12, face ="bold"),
        panel.border = element_rect(fill=NA,colour = NA),
        plot.caption = element_text(hjust = 0.5),
        axis.title = element_blank(),
        axis.text = element_blank(),
        plot.margin = unit(c(0.5,0,0,0), "cm"))+
  geom_point(data = oth.obs, size = 5, shape='*')

Fig11d.o <- ggplot(oth.pred, aes(Mean.human.dens.per.patch, Percent.total.overlap))+
  geom_jitter(size=1, position = position_jitter(width = 0.15, height = 0.15), 
              alpha = 0.08, color = "tomato2")+
  geom_smooth(data = data.smooth,
              size = 1.5, span = 1, color = "firebrick3", fill=NA) +
  scale_x_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 16))+
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, 100))+
  labs(x="Human density")+ 
  theme(legend.position = "none",
        panel.border = element_rect(fill=NA,colour = NA),
        plot.caption = element_text(hjust = 0.5),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

# Combine all: (jittering & alignment means drops some outer pts)
Fig11a <- plot_grid(Fig11a.ts, Fig11a.o, ncol=1, align = c("v"))
Fig11b <- plot_grid(Fig11b.ts, Fig11b.o, ncol=1, align = c("v"))
Fig11c <- plot_grid(Fig11c.ts, Fig11c.o, ncol=1, align = c("v"))
Fig11d <- plot_grid(Fig11d.ts, Fig11d.o, ncol=1, align = c("v"))
Fig11 <- plot_grid(Fig11a, Fig11b, Fig11c, Fig11d, ncol=2, 
                              rel_widths = c(1,0.85,1,0.85),
                              rel_heights = c(0.9,1))

tiff("Figure SI11.tif", height=3000, width=1900,
     units="px", compression = c("none"), res=300, pointsize = 12)
Fig11
dev.off()

################################################################################
#### Figure S12
#### SI Version of Figure 6, Seasonal Patterns
data.summer <- oth.pred %>% 
  mutate(Percent.seasonal.overlap = Sum.s.overlap / Sum.s.selected.patches *100) %>% 
  select(c(Sum.s.selected.patches, Percent.seasonal.overlap)) %>% 
  mutate(Season = "Summer") %>% 
  rename(Territory.size = Sum.s.selected.patches)
data.winter <- oth.pred %>% 
  mutate(Percent.seasonal.overlap = Sum.w.overlap / Sum.w.selected.patches *100) %>% 
  select(c(Sum.w.selected.patches, Percent.seasonal.overlap)) %>% 
  mutate(Season = "Winter") %>% 
  rename(Territory.size = Sum.w.selected.patches)

data.plot <- rbind(data.summer, data.winter)
seas.cols <- c("palegreen3","skyblue2")
data.plot$Group[data.plot$Season == "Summer"] <- 1
data.plot$Group[data.plot$Season == "Winter"] <- 2

Fig12.ts <- ggplot(data.plot, aes(x=Territory.size, color = Season, fill = Season))+
  geom_density(alpha = 0.4)+
  labs(x = expression(Seasonal~territory~size~(km^2)))+  
  scale_x_continuous(breaks = seq(0,1300,200), limits = c(0,NA))+
  scale_fill_manual(values = c(seas.cols))+  
  scale_color_manual(values = c(seas.cols))+  
  theme(legend.position = "none",
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.line.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

Fig12.o <- ggplot(data.plot, aes(x=Percent.seasonal.overlap, color = Season, fill = Season))+
  geom_density(alpha = 0.4)+
  labs(x = "Seasonal territory overlap (%)")+  
  scale_x_continuous(breaks = seq(0,100,10), limits = c(0,100))+
  scale_fill_manual(values = c(seas.cols))+  
  scale_color_manual(values = c(seas.cols))+  
  theme(legend.position = c(0.7, 0.7),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.line.y = element_blank(),
        plot.margin = unit(c(0,0,0,0), "cm"))

Fig12 <- plot_grid(Fig12.ts, Fig12.o, ncol=2, align = c("hv"))

tiff("Figure SI12.tif", height=1100, width=2200,
     units="px", compression = c("none"), res=300, pointsize = 12)
Fig12
dev.off()


################################################################################
#### Figure S13, Prey Predictions
# Prep prey predictions (50%, 75%, 125%, and 150% of recent):
prey.pred$Prey.brks <- cut(prey.pred$Prey.adjustment, 
                           breaks=c(0,0.5,0.75,1,1.25,1.5),
                           labels=c("50% of recent", "75% of recent", "no change", 
                                    "125% of recent", "150% of recent"))
prey.pred %>%
  group_by(Prey.brks) %>%
  summarize(Population_size = mean(Number.of.packs, na.rm = TRUE),
            Mean_territory_size = mean(Total.size, na.rm = TRUE),
            Mean_overlap = mean(Percent.total.overlap, na.rm=TRUE))

Fig13a <- ggplot(prey.pred, aes(Total.size, fill=Prey.brks))+
  geom_density(alpha=0.45)+
  viridis::scale_fill_viridis(discrete=T,option="D", name="Change in prey density")+
  scale_x_continuous(breaks = scales::pretty_breaks(5))+
  labs(x=expression(Territory~size~(km^2))) + 
  theme(legend.position = c(0.75,0.6),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        panel.border = element_blank(),
        axis.line.y = element_blank())

Fig13b <- ggplot(prey.pred, aes(Percent.total.overlap, fill=Prey.brks))+
  geom_density(alpha=0.4)+
  viridis::scale_fill_viridis(discrete=T,option="D", name="Change in prey density")+
  scale_x_continuous(breaks = scales::pretty_breaks(5))+
  labs(x="Territory overlap (%)") + 
  theme(legend.position = "none",
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        panel.border = element_blank(),
        axis.line.y = element_blank())

Fig13 <- plot_grid(Fig13a, Fig13b, ncol=1)

tiff("Figure SI13.tif", height=2200, width=2200,
     units="px", compression = c("none"), res=300, pointsize = 12)
Fig13
dev.off()

################################################################################
#### Figure S14, Competition Predictions
# Upper panel:
data.plot <- comp.pred %>% 
  filter(Ecoregion <= 41) %>% 
  mutate(Ecoregion = as.factor(Ecoregion)) %>% 
  group_by(Ecoregion, Density) %>% 
  summarize(mean.size = mean(Total.size)) 
data.plot$Ecoregion <- factor(data.plot$Ecoregion, levels=c("15","16","41","17"))
eco.cols.w <- c("palegreen4","palegreen3","aquamarine2","lawngreen")

Fig14upper <- ggplot(data.plot, aes(x = Density, y = mean.size, 
                                      group=Ecoregion, color=Ecoregion)) + 
  geom_smooth(size=1.5, se=F) +
  labs(x=expression(Pack~Density~(per~1000~km^2)), 
       y=expression(Territory~size~(km^2))) +
  scale_x_continuous(limits = c(0.1, 2.5)) +
  scale_y_continuous(breaks = scales::pretty_breaks(10)) +
  scale_color_manual(values = c(eco.cols.w), 
                     labels = c("Northern Rockies","Idaho Batholith",
                                "Canadian Rockies","Middle Rockies","")) +
  theme(legend.position = c(0.8, 0.7))

# Lower panel:
# Reduce competition to 0.5 incremental densities:
data.bydensity <- comp.pred %>% 
  filter(Density == 0.1| Density == 0.5| Density == 1.0| Density == 1.5|
           Density == 2.0| Density == 2.5) %>% 
  filter(Ecoregion <= 41) %>% 
  mutate(Ecoregion = as.factor(Ecoregion))
data.bydensity.sub <- subset(data.bydensity, Ecoregion == "15")
Fig14a <- ggplot(data.bydensity.sub, aes(Ecoregion, Total.size)) +
  labs(title="Northern Rockies", y=expression(Territory~size~(km^2))) +
  scale_y_continuous(breaks = scales::pretty_breaks(5), limits = c(0, NA))+
  theme(panel.border = element_rect(fill=NA,colour = "white"),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.line.y=element_blank(),
        plot.title = element_text(size=12, hjust=0.5),
        plot.margin = unit(c(1,0.2,0.2,0.2), "cm"))+
  geom_flat_violin(col="black", size=0.5, fill = "palegreen4", width = 1, trim=FALSE)+
  coord_flip() + # flip or not
  stat_summary(fun=mean, geom="point", shape=10, size=3, color="black", fill="black") + 
  stat_summary(fun=median, geom="point", shape=3, size=5, color="black", fill="black") + 
  facet_grid(Density~.)

data.bydensity.sub <- subset(data.bydensity, Ecoregion == "16")
Fig14b <- ggplot(data.bydensity.sub, aes(Ecoregion, Total.size)) +
  labs(title="Idaho Batholith", y=expression(Territory~size~(km^2))) +
  scale_y_continuous(breaks = scales::pretty_breaks(6), limits = c(0, NA))+
  theme(panel.border = element_rect(fill=NA,colour = "white"),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.line.y=element_blank(),
        plot.title = element_text(size=12, hjust=0.5),
        plot.margin = unit(c(1,0.2,0.2,0.2), "cm"))+
  geom_flat_violin(col="black", size=0.5, fill = "palegreen3", width = 1, trim=FALSE)+ 
  coord_flip() + # flip or not
  stat_summary(fun=mean, geom="point", shape=10, size=3, color="black", fill="black") + 
  stat_summary(fun=median, geom="point", shape=3, size=5, color="black", fill="black") + 
  facet_grid(Density~.)

data.bydensity.sub <- subset(data.bydensity, Ecoregion == "41")
Fig14c <- ggplot(data.bydensity.sub, aes(Ecoregion, Total.size)) +
  labs(title="Canadian Rockies", y=expression(Territory~size~(km^2))) +
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, NA))+
  theme(panel.border = element_rect(fill=NA,colour = "white"),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.line.y=element_blank(),
        plot.title = element_text(size=12, hjust=0.5),
        plot.margin = unit(c(1,0.2,0.2,0.2), "cm"))+
  geom_flat_violin(col="black", size=0.5, fill = "aquamarine2", width = 1, trim=FALSE)+ 
  coord_flip() + # flip or not
  stat_summary(fun=mean, geom="point", shape=10, size=3, color="black", fill="black") + 
  stat_summary(fun=median, geom="point", shape=3, size=5, color="black", fill="black") + 
  facet_grid(Density~.)

data.bydensity.sub <- subset(data.bydensity, Ecoregion == "17")
Fig14d <- ggplot(data.bydensity.sub, aes(Ecoregion, Total.size)) +
  labs(title="Middle Rockies", x = "Density", y=expression(Territory~size~(km^2))) +
  scale_y_continuous(breaks = scales::pretty_breaks(7), limits = c(0, NA))+
  theme(panel.border = element_rect(fill=NA,colour = "white"),
        axis.title.y = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.line.y=element_blank(),
        plot.title = element_text(size=12, hjust=0.5),
        plot.margin = unit(c(1,0.2,0.2,0.2), "cm"))+
  geom_flat_violin(col="black", size=0.5, fill = "lawngreen", width = 1, trim=FALSE)+ 
  coord_flip() + # flip or not
  stat_summary(fun=mean, geom="point", shape=10, size=3, color="black", fill="black") + 
  stat_summary(fun=median, geom="point", shape=3, size=5, color="black", fill="black") + 
  facet_grid(Density~.)  

Fig14lower <- plot_grid(Fig14a,Fig14b,Fig14c,Fig14d, ncol=4)

Fig14 <- plot_grid(Fig14upper, Fig14lower, ncol=1, rel_heights =  c(0.65,1))

tiff("Figure SI14.tif", height=2400, width=2800,
     units="px", compression = c("none"), res=300, pointsize = 12)
Fig14
dev.off()

################################################################################
#### Figure S15, Occupancy Predictions
data.plot <- comp.pred %>% 
  group_by(Density, Area.occupied) %>% 
  summarize(Area.occupied = first(Area.occupied))

theme_set(theme_grey(base_size = 12))
options(scipen=10000)
Fig15 <- ggplot(data.plot, aes(Density, Area.occupied))+
  geom_jitter(size=1, position = position_jitter(width = 0.05, height = 0.05),
              alpha = 0.15, color = "#00CC66")+
  geom_smooth(size = 2, span = 1,  fill=NA, color="#009900", method = "loess") +
  scale_x_continuous(breaks = scales::pretty_breaks(7))+
  scale_y_continuous(breaks = scales::pretty_breaks(10), limits = c(0, NA)) +
  labs(y=expression(Area~Occupied~(km^2)),x="Pack Density") +
  theme(legend.position = "none",
        panel.border = element_rect(fill=NA,colour = NA),
        plot.margin = unit(c(0,0,0,0), "cm"))
Fig15

tiff("Figure SI15.tif", height=1500, width=2200, units="px",
     compression = c("none"), res=500, pointsize = 12)
Fig15
dev.off()